<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="fr">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy d&apos;application</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Type de proxy</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresse IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Optionnel</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Cochez &quot;Utiliser un proxy&quot; dans le menu contextuel de l&apos;application dans Lanceur après avoir configuré</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresse IP non valide</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Port invalide</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Déconnecter</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connexion en cours</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Déconnecter</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Êtes-vous sûr de vouloir supprimer cette configuration ?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Connexion filaire %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Point d&apos;accès</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Connexion sans fil %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Connexion PPPoE %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Nouveau VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Type de VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exporter</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy pour les applications</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Point d&apos;accès personnel</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Détails du réseau</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy système</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Réseau filaire</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Réseau sans fil</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Mode avion</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Adaptateur réseau filaire</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Ajouter une Connection Réseau</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Adaptateur de réseau sans fil</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Se connecter à un réseau caché</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Créer une connexion PPPoE</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>État du VPN</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Créer un VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importer un VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Type de proxy</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL de configuration</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresse IP</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Point d&apos;accès</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Créer un point d&apos;accès</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Bande</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Passerelle</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primaire</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Masque de sous-réseau</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Préfixe</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Vitesse</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Mode avion</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Adresse DNS non valide</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Ne pas lier</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Adresse MAC du périphérique</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Adresse MAC clonée</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personnaliser MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Le nom existe déjà</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Connexion automatique</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Point d&apos;accès</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Ajouter des paramètres</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Créer un point d&apos;accès</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>Adresse IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>passerelle</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Adresse IP en double</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresse IP non valide</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Masque de réseau non valide</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Une seule passerelle est autorisée</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passerelle invalide</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Masque de réseau</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Adresse IP en double</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresse IP non valide</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Une seule passerelle est autorisée</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passerelle invalide</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Préfixe</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatique</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresse IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>passerelle</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Uniquement appliqué dans les ressources correspondantes</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Méthode</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Masque de réseau</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Préfixe</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Adresse IP non valide</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Masque de réseau non valide</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passerelle invalide</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflit IP</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Méthode</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatique</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Détails du réseau</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy système</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy d&apos;application</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Mode avion</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Détails du réseau</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflit IP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Désactivé</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatique</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Configurer par Network Manager</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Point d&apos;accès personnel</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Service</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Refuser l&apos;authentification EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Refuser l&apos;authentification PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Refuser l&apos;authentification CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Refuser l&apos;authentification MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Refuser l&apos;authentification MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Pas de compression de données BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Pas de compression de données de dégonflage</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Pas de compression d&apos;en-tête TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Pas de compression de champ de protocole</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Pas de compression d&apos;adresse/de contrôle</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Envoyer des paquets d&apos;écho PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Utiliser MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>MPPE 128 bits</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE en état</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Créer une connection PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy système</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Type de proxy</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatique</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Optionnel</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Proxy HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Proxy HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Proxy FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Proxy SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignorer les configurations de proxy pour les hôtes et domaines ci-dessus</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL de configuration</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Sécurité</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>SAUT</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS par tunnel</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP protégé</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Enregistrer le mot de passe de cet utilisateur</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Enregistrer le mot de passe pour tous les utilisateurs</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Toujours me demander</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Désactivé</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonyme</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Authentifié</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Tous</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatique</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Version 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Version 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Authentification EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identité</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Options du Mdp</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clé privée</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Cert CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Cert utilisateur</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Identifiant anonyme</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Approvisionnement</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Fichier PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Authentification Interne</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Version PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Mdp privé</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Mot de passe incorrect</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personnel</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personnel</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sécurité</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Clé</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Sécurité requise</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Mot de passe incorrect</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personnel</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Entreprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personnel</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Clé partagée</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Système ouvert</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sécurité</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Authentification</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Clé</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN avancé</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Personnaliser le port de passerelle</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Port de passerelle</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Personnaliser l&apos;intervalle de renégociation</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Intervalle de renégociation</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Utiliser la compression de données LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Utiliser la connexion TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Utiliser un périphérique TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Personnaliser le tunnel MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Tailles de fragments UDP personnalisés</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Taille de fragments UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Restreindre le Tunnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Randomiser les hôtes distants</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN avancé</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (par défaut)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Sécurisé (par défaut)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Faible</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T lorsqu&apos;il est disponible (par défaut)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T Toujours</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Désactivé</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Groupe 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Groupe 2 (par défaut)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Groupe 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Serveur (par défaut)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Groupe 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domaine</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Vendeur</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Chiffrement</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Mode de traversée NAT</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Groupe IKE DH</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Confidentialité de l&apos;envoi</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Port local</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Désactiver la détection des homologues morts</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Activer IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nom de groupe</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID de groupe</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Clé pré-partagée</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algorithmes Phase1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algorithmes de la Phase2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passerelle invalide</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>passerelle</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Cert CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Autoriser le cheval de Troie Cisco Secure Desktop</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Script CSD</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Cert utilisateur</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clé privée</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Utiliser FSID pour la clé de la phrase secrète</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passerelle invalide</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certificats (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certificats avec mot de passe (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Clé statique</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Sauvegardé</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Demander</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Non requis</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>passerelle</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Type d&apos;authentification</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Cert CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Cert utilisateur</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clé privée</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Options du Mdp</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Mdp privé</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Personnaliser la clé de direction</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Clé de direction</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP à distance</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP locale</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Tous disponibles (par défaut)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40 bits (moins sécurisé)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128 bits (le plus sécurisé)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Refuser l&apos;authentification EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Refuser l&apos;authentification PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Refuser l&apos;authentification CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Refuser l&apos;authentification MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Refuser l&apos;authentification MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Pas de compression de données BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Pas de compression de données de dégonflage</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Pas de compression d&apos;en-tête TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Pas de compression de champ de protocole</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Pas de compression d&apos;adresse/de contrôle</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Envoyer des paquets d&apos;écho PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Utiliser MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sécurité</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE en état</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>État du VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Créer un VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importer un VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Erreur d&apos;importation</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Erreur de fichier</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Non requis</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Type de proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP du serveur</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Réessayer indéfiniment quand il y a échec</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Fichier CA</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Ignorer les avertissements de certificat</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Utiliser les extensions de nom d&apos;hôte TLS</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Sécurité du VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Chiffrer</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Auth HMAC</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passerelle invalide</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Sauvegardé</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Demander</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Non requis</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>passerelle</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Options du Mdp</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Domaine NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP du serveur</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passerelle invalide</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clé privée</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Agent SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Carte à puce</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Clé pré-partagée</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>passerelle</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Cert CA</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Type d&apos;authentification</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Cert utilisateur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Demander une adresse IP interne</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Appliquer l&apos;encapsulation UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Utiliser la compression IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Activer les propositions de chiffrement personnalisées</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Authentification VPN TLS</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Serveur</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Le sujet correspond</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Type de certificat distant</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Fichier clé</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Personnaliser la clé de direction</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Clé de direction</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Passerelle invalide</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Sauvegardé</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Demander</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Non requis</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>passerelle</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Options du Mdp</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nom de groupe</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Mdp du groupe</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Utiliser l&apos;authentification hybride</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Fichier CA</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Brancher le câble réseau en premier</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Adaptateur réseau filaire</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Ajouter Connection Réseau</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Sélectionner les paramètre</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Adaptateur de réseau sans fil</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Fermer le point d&apos;accès</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Désactivez d&apos;abord le point d&apos;accès si vous souhaitez vous connecter à un réseau sans fil</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Se connecter à un réseau caché</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Ne pas lier</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Obligatoire</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Adresse MAC du périphérique</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personnaliser MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>